@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.text.resources.cldr.ext;
@@ -90,6 +98,7 @@ public class FormatData_my extends ListResourceBundle {
             "",
         };
         final String metaValue_generic_DateFormatItem_yyyyMMMd = "G d MMM y";
+        final String metaValue_generic_DateFormatItem_yyyyMMMEd = "G y MMM d၊ E";
         final String[] metaValue_MonthNames = new String[] {
             "ဇန်နဝါရီ",
             "ဖေဖော်ဝါရီ",
@@ -184,15 +193,19 @@ public class FormatData_my extends ListResourceBundle {
         };
         final String metaValue_generic_DateFormatItem_hm = "a h:mm";
         final String metaValue_generic_DateFormatItem_Ehm = "E a h:mm";
+        final String metaValue_generic_DateFormatItem_hv = "v a h";
         final String metaValue_generic_DateFormatItem_hms = "a h:mm:ss";
         final String metaValue_generic_DateFormatItem_hmv = "v a h:mm";
         final String metaValue_generic_DateFormatItem_hmsv = "v a h:mm:ss";
         final String metaValue_generic_DateFormatItem_yw = "Y ခု w ပတ်မြောက်";
+        final String metaValue_generic_DateFormatItem_Hv = "v HH";
         final String metaValue_generic_DateFormatItem_MMMMEd = "MMMM d E";
         final String metaValue_generic_DateFormatItem_EBhm = "E B h:mm";
         final String metaValue_generic_DateFormatItem_MMMEd = "MMM d E";
+        final String metaValue_generic_DateFormatItem_GyMEd = "G y-MM-dd၊ E";
         final String metaValue_generic_DateFormatItem_Bh = "B h";
         final String metaValue_generic_DateFormatItem_h = "a h";
+        final String metaValue_generic_DateFormatItem_EBh = "E B h";
         final String metaValue_generic_DateFormatItem_Hmsv = "v HH:mm:ss";
         final String metaValue_generic_DateFormatItem_GyMd = "G y/M/d";
         final String metaValue_generic_DateFormatItem_MMMMW = "MMMM လ W ပတ်မြောက်";
@@ -203,9 +216,9 @@ public class FormatData_my extends ListResourceBundle {
         final String metaValue_generic_DateFormatItem_Md = "d/M";
         final String metaValue_generic_DateFormatItem_EBhms = "E B h:mm:ss";
         final String metaValue_generic_DateFormatItem_Ed = "d ရက် E";
+        final String metaValue_generic_DateFormatItem_Eh = "E a h";
         final String metaValue_generic_DateFormatItem_Bhm = "B h:mm";
         final String metaValue_generic_DateFormatItem_MEd = "d/M E";
-        final String metaValue_generic_DateFormatItem_GyMMMEd = "G y/ MMM d/ E";
         final String metaValue_generic_DateFormatItem_Hmv = "v HH:mm";
         final String metaValue_generic_DateFormatItem_yMd = "d/M/y";
         final String[] metaValue_java_time_generic_DatePatterns = new String[] {
@@ -249,16 +262,20 @@ public class FormatData_my extends ListResourceBundle {
             { "generic.DateTimePatterns", metaValue_generic_DateTimePatterns },
             { "generic.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "generic.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "generic.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "generic.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "generic.DateFormatItem.yyyyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
             { "generic.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "generic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "generic.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "generic.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "generic.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "generic.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
             { "generic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "generic.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "generic.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "generic.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "generic.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "generic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "generic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "generic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
@@ -266,14 +283,16 @@ public class FormatData_my extends ListResourceBundle {
             { "generic.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
             { "generic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
             { "generic.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "generic.DateFormatItem.yyyyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "generic.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
             { "generic.DateFormatItem.yyyyMd", "GGGGG dd/MM/Y" },
             { "generic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "generic.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "generic.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "generic.DateFormatItem.Eh", metaValue_generic_DateFormatItem_Eh },
             { "generic.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "generic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "generic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "generic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "generic.DateFormatItem.yyyyM", "G M/y" },
             { "generic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "generic.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
@@ -329,15 +348,19 @@ public class FormatData_my extends ListResourceBundle {
             { "DayPeriodRules", "midnight:00:00;noon:12:00;night1:19:00-24:00;afternoon1:12:00-16:00;morning1:00:00-12:00;evening1:16:00-19:00" },
             { "DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
             { "DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
@@ -348,9 +371,10 @@ public class FormatData_my extends ListResourceBundle {
             { "DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "DateFormatItem.Eh", metaValue_generic_DateFormatItem_Eh },
             { "DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -367,15 +391,19 @@ public class FormatData_my extends ListResourceBundle {
             { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
             { "buddhist.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "buddhist.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "buddhist.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "buddhist.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "buddhist.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "buddhist.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "buddhist.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "buddhist.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "buddhist.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "buddhist.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
             { "buddhist.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "buddhist.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "buddhist.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "buddhist.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "buddhist.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "buddhist.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "buddhist.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "buddhist.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
@@ -386,9 +414,10 @@ public class FormatData_my extends ListResourceBundle {
             { "buddhist.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "buddhist.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "buddhist.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "buddhist.DateFormatItem.Eh", metaValue_generic_DateFormatItem_Eh },
             { "buddhist.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "buddhist.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "buddhist.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "buddhist.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "buddhist.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "buddhist.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
             { "japanese.MonthNames", metaValue_MonthNames },
@@ -412,15 +441,19 @@ public class FormatData_my extends ListResourceBundle {
             },
             { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "japanese.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "japanese.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "japanese.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "japanese.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "japanese.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "japanese.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "japanese.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "japanese.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "japanese.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
             { "japanese.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "japanese.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "japanese.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "japanese.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "japanese.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "japanese.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "japanese.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "japanese.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
@@ -431,9 +464,10 @@ public class FormatData_my extends ListResourceBundle {
             { "japanese.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "japanese.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "japanese.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "japanese.DateFormatItem.Eh", metaValue_generic_DateFormatItem_Eh },
             { "japanese.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "japanese.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "japanese.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "japanese.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "japanese.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "japanese.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
             { "roc.MonthNames", metaValue_MonthNames },
@@ -449,15 +483,19 @@ public class FormatData_my extends ListResourceBundle {
             { "roc.DatePatterns", metaValue_generic_DatePatterns },
             { "roc.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "roc.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "roc.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "roc.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "roc.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "roc.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "roc.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "roc.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "roc.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "roc.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
             { "roc.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "roc.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "roc.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "roc.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "roc.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "roc.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "roc.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "roc.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
@@ -468,9 +506,10 @@ public class FormatData_my extends ListResourceBundle {
             { "roc.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "roc.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "roc.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "roc.DateFormatItem.Eh", metaValue_generic_DateFormatItem_Eh },
             { "roc.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "roc.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "roc.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "roc.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "roc.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "roc.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
             { "islamic.DayNames", metaValue_generic_DayNames },
@@ -483,15 +522,19 @@ public class FormatData_my extends ListResourceBundle {
             { "islamic.DatePatterns", metaValue_generic_DatePatterns },
             { "islamic.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "islamic.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "islamic.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "islamic.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "islamic.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "islamic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "islamic.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "islamic.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "islamic.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "islamic.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
             { "islamic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "islamic.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "islamic.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "islamic.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "islamic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "islamic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
@@ -502,22 +545,27 @@ public class FormatData_my extends ListResourceBundle {
             { "islamic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "islamic.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "islamic.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "islamic.DateFormatItem.Eh", metaValue_generic_DateFormatItem_Eh },
             { "islamic.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "islamic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "islamic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "islamic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "islamic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "islamic.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
             { "islamic-civil.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "islamic-civil.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "islamic-civil.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "islamic-civil.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "islamic-civil.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "islamic-civil.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "islamic-civil.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "islamic-civil.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "islamic-civil.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "islamic-civil.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
             { "islamic-civil.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "islamic-civil.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic-civil.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "islamic-civil.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "islamic-civil.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "islamic-civil.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "islamic-civil.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic-civil.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
@@ -528,22 +576,27 @@ public class FormatData_my extends ListResourceBundle {
             { "islamic-civil.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "islamic-civil.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "islamic-civil.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "islamic-civil.DateFormatItem.Eh", metaValue_generic_DateFormatItem_Eh },
             { "islamic-civil.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "islamic-civil.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "islamic-civil.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "islamic-civil.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "islamic-civil.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "islamic-civil.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
             { "islamic-umalqura.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "islamic-umalqura.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "islamic-umalqura.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "islamic-umalqura.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "islamic-umalqura.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "islamic-umalqura.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "islamic-umalqura.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "islamic-umalqura.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "islamic-umalqura.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "islamic-umalqura.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
             { "islamic-umalqura.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "islamic-umalqura.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic-umalqura.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "islamic-umalqura.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "islamic-umalqura.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "islamic-umalqura.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "islamic-umalqura.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic-umalqura.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
@@ -554,9 +607,10 @@ public class FormatData_my extends ListResourceBundle {
             { "islamic-umalqura.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "islamic-umalqura.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "islamic-umalqura.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "islamic-umalqura.DateFormatItem.Eh", metaValue_generic_DateFormatItem_Eh },
             { "islamic-umalqura.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "islamic-umalqura.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "islamic-umalqura.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "islamic-umalqura.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "islamic-umalqura.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "islamic-umalqura.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
             { "calendarname.islamic-civil", "အစ္စလာမ်မစ် ပြက္ခဒိန်" },
